==> docker-client-6.2.0-sources.jar: com/spotify/docker/client/messages/swarm/Resources.java <==
/*-
 * -\-\-
 * docker-client
 * --
 * Copyright (C) 2016 Spotify AB
 * --
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * -/-/-
 */

package com.spotify.docker.client.messages.swarm;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.ANY;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.common.base.MoreObjects;

import java.util.Objects;

@JsonAutoDetect(fieldVisibility = ANY, getterVisibility = NONE, setterVisibility = NONE)
public class Resources {

  @JsonProperty("NanoCPUs")
  private Long nanoCpus;

  @JsonProperty("MemoryBytes")
  private Long memoryBytes;

  public Long nanoCpus() {
    return nanoCpus;
  }

  public Long memoryBytes() {
    return memoryBytes;
  }

  public static class Builder {

    private Resources resources = new Resources();

    public Builder withNanoCpus(Long nanoCpus) {
      resources.nanoCpus = nanoCpus;
      return this;
    }

    public Builder withMemoryBytes(Long memoryBytes) {
      resources.memoryBytes = memoryBytes;
      return this;
    }

    public Resources build() {
      return resources;
    }
  }

  public static Resources.Builder builder() {
    return new Resources.Builder();
  }

  @Override
  public boolean equals(final Object obj) {
    if (this == obj) {
      return true;
    }
    if (obj == null || getClass() != obj.getClass()) {
      return false;
    }

    final Resources that = (Resources) obj;

    return Objects.equals(this.nanoCpus, that.nanoCpus)
           && Objects.equals(this.memoryBytes, that.memoryBytes);
  }

  @Override
  public int hashCode() {
    return Objects.hash(nanoCpus, memoryBytes);
  }

  @Override
  public String toString() {
    return MoreObjects.toStringHelper(this)
        .add("nanoCpus", nanoCpus)
        .add("memoryBytes", memoryBytes)
        .toString();
  }
}

==> docker-client-7.0.0-rc2-sources.jar: com/spotify/docker/client/messages/swarm/Resources.java <==
/*-
 * -\-\-
 * docker-client
 * --
 * Copyright (C) 2016 Spotify AB
 * --
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * -/-/-
 */

package com.spotify.docker.client.messages.swarm;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.ANY;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.auto.value.AutoValue;

import javax.annotation.Nullable;

@AutoValue
@JsonAutoDetect(fieldVisibility = ANY, getterVisibility = NONE, setterVisibility = NONE)
public abstract class Resources {

  @Nullable
  @JsonProperty("NanoCPUs")
  public abstract Long nanoCpus();

  @JsonProperty("MemoryBytes")
  public abstract Long memoryBytes();

  @AutoValue.Builder
  public abstract static class Builder {

    public abstract Builder nanoCpus(Long nanoCpus);

    public abstract Builder memoryBytes(Long memoryBytes);

    public abstract Resources build();
  }

  public static Resources.Builder builder() {
    return new AutoValue_Resources.Builder();
  }

  @JsonCreator
  static Resources create(
      @JsonProperty("NanoCPUs") final Long nanoCpus,
      @JsonProperty("MemoryBytes") final Long memoryBytes) {
    return builder()
        .nanoCpus(nanoCpus)
        .memoryBytes(memoryBytes)
        .build();
  }
}
